@@ -1,7 +1,18 @@
-# clean: Extract only converged replications in the result object
+# clean: Extract only simultaneous converged replications in the result objects
 
-clean <- function(object) {
-    converged <- object@converged
+clean <- function(...) {
+	object.l <- list(...)
+	converged <- sapply(object.l, slot, name="converged")
+	allConverged <- apply(converged, 1, all)
+	if(all(!allConverged)) stop("All replications in the result object are not convergent. Thus, the result object cannot be used.")
+	object.l <- lapply(object.l, cleanSimResult, converged=allConverged)
+	if(length(object.l) == 1) object.l <- object.l[[1]]
+	return(object.l)
+} 
+
+# cleanSimResult: Extract only converged replications in a result object
+cleanSimResult <- function(object, converged=NULL) {
+    if(is.null(converged)) converged <- object@converged
     object@nRep <- sum(converged)
     object@coef <- object@coef[converged, ]
     object@se <- object@se[converged, ]
@@ -21,5 +32,6 @@ clean <- function(object) {
         object@pmMCAR <- object@pmMCAR[converged]
     if (length(object@pmMAR) > 1) 
         object@pmMAR <- object@pmMAR[converged]
+	object@converged <- converged
     return(object)
-} 
+} 
\ No newline at end of file
