@@ -2,8 +2,9 @@
 
 extractLavaanFit <- function(Output) {
     Indices <- fitmeasures(Output)
-    result <- c(Indices["chisq"], Indices["df"], Indices["pvalue"], Indices["baseline.chisq"], Indices["baseline.df"], Indices["baseline.pvalue"], Indices["cfi"], Indices["tli"], Indices["aic"], 
-        Indices["bic"], Indices["rmsea"], Indices["rmsea.ci.lower"], Indices["rmsea.ci.upper"], Indices["srmr"])
+    result <- c(Indices["chisq"], Indices["df"], Indices["pvalue"], Indices["baseline.chisq"], Indices["baseline.df"], Indices["baseline.pvalue"], 
+        Indices["cfi"], Indices["tli"], Indices["aic"], Indices["bic"], Indices["rmsea"], Indices["rmsea.ci.lower"], Indices["rmsea.ci.upper"], 
+        Indices["srmr"])
     old.name <- c("chisq", "cfi", "tli", "aic", "bic", "rmsea", "srmr")
     new.name <- c("Chi", "CFI", "TLI", "AIC", "BIC", "RMSEA", "SRMR")
     name <- names(result)
